import eremitalpa

from .bio import (
    amino_acid_colors,
    AMINO_ACIDS,
    consensus_seq,
    filter_similar_hd,
    find_mutations,
    find_substitutions,
    grouped_sample,
    group_sequences_by_character_at_site,
    hamming_dist_lt,
    hamming_dist,
    load_fasta,
    pairwise_hamming_dists,
    sloppy_translate,
    Substitution,
    TiedCounter,
    variable_sites,
    write_fasta,
)
from .eremitalpa import (
    color_stack,
    compare_trees,
    compute_tree_layout,
    deepest_leaf,
    get_trunk,
    MultipleSequenceAlignment,
    node_x_y,
    node_x_y_from_taxon_label,
    plot_leaves_with_labels,
    plot_subs_on_tree,
    plot_tree_with_subplots,
    plot_tree,
    prune_nodes_with_labels,
    read_iqtree_ancestral_states,
    read_raxml_ancestral_sequences,
    taxon_in_node_label,
    taxon_in_node_labels,
    Tree,
)
from .influenza import (
    _cluster_motifs,
    aa_counts_thru_time,
    cluster_colors,
    cluster_from_ha_2,
    cluster_from_ha,
    cluster_transitions,
    Cluster,
    clusters,
    ClusterTransition,
    guess_clusters_in_tree,
    hamming_to_all_clusters,
    hamming_to_cluster,
    NHSeason,
    plot_aa_freq_thru_time,
    plot_tree_coloured_by_cluster,
    translate_segment,
    translate_trim_default_ha,
)
from .flu_wider import b7, wider5, wider10, wider15
from .lib import (
    annotate_points,
    cal_months_diff,
    compute_errorbars,
    find_runs,
    jupyter_code_cell_toggle,
    log_df_func,
    split_pairs,
)
from .spread_points import spread_points

from importlib.metadata import version, PackageNotFoundError

try:
    __version__ = version("eremitalpa")
except PackageNotFoundError:
    pass

__all__ = [
    "__version__",
    "_cluster_motifs",
    "aa_counts_thru_time",
    "amino_acid_colors",
    "AMINO_ACIDS",
    "annotate_points",
    "b7",
    "cal_months_diff",
    "cluster_colors",
    "cluster_from_ha_2",
    "cluster_from_ha",
    "cluster_transitions",
    "Cluster",
    "clusters",
    "ClusterTransition",
    "color_stack",
    "compare_trees",
    "compute_errorbars",
    "compute_tree_layout",
    "consensus_seq",
    "deepest_leaf",
    "eremitalpa",
    "filter_similar_hd",
    "find_mutations",
    "find_runs",
    "find_substitutions",
    "get_trunk",
    "grouped_sample",
    "group_sequences_by_character_at_site",
    "guess_clusters_in_tree",
    "hamming_dist_lt",
    "hamming_dist",
    "hamming_to_all_clusters",
    "hamming_to_cluster",
    "jupyter_code_cell_toggle",
    "load_fasta",
    "log_df_func",
    "MultipleSequenceAlignment",
    "NHSeason",
    "node_x_y",
    "node_x_y_from_taxon_label",
    "pairwise_hamming_dists",
    "plot_aa_freq_thru_time",
    "plot_leaves_with_labels",
    "plot_subs_on_tree",
    "plot_subs_on_tree",
    "plot_tree_coloured_by_cluster",
    "plot_tree_with_subplots",
    "plot_tree",
    "prune_nodes_with_labels",
    "read_iqtree_ancestral_states",
    "read_raxml_ancestral_sequences",
    "sloppy_translate",
    "split_pairs",
    "spread_points",
    "Substitution",
    "taxon_in_node_label",
    "taxon_in_node_labels",
    "TiedCounter",
    "translate_segment",
    "translate_trim_default_ha",
    "Tree",
    "variable_sites",
    "wider10",
    "wider15",
    "wider5",
    "write_fasta",
]
